@@ -4,7 +4,7 @@ from azure.storage.blob import BlobClient
 
 class PyblobLogger:
 
-    DEBUG_LEVEL = logging.WARNING
+    DEBUG_LEVEL = logging.DEBUG
     ERROR_LEVEL = logging.ERROR
     LOGGING_FORMAT = '%(asctime)s - %(name)s - %(message)s'
     DIRECTORY_NAME_LENGTH = 5
